# eric7.WebBrowser.UrlBar.StackedUrlBar

Module implementing a widget to stack url bars.

### Global Attributes

None

### Classes

StackedUrlBar | Class implementing a widget to stack URL bars.

### Functions

None

## StackedUrlBar

Class implementing a widget to stack URL bars.

### Derived from

QStackedWidget

### Class Attributes

None

### Class Methods

None

### Methods

StackedUrlBar | Constructor
currentUrlBar | Public method to get a reference to the current URL bar.
moveBar | Public slot to move an URL bar.
urlBar | Public method to get a reference to the URL bar for a given index.
urlBars | Public method to get a list of references to all URL bars.

### Static Methods

None

#### StackedUrlBar (Constructor)

StackedUrlBar(parent=None)

Constructor

parent (QWidget)
  reference to the parent widget

#### StackedUrlBar.currentUrlBar

currentUrlBar()

Public method to get a reference to the current URL bar.

Return:
  reference to the current URL bar

Return Type:
  UrlBar

#### StackedUrlBar.moveBar

moveBar(from_, to_)

Public slot to move an URL bar.

from_ (int)
  index of URL bar to be moved
to_ (int)
  index to move the URL bar to

#### StackedUrlBar.urlBar

urlBar(index)

Public method to get a reference to the URL bar for a given index.

index (int)
  index of the url bar

Return:
  reference to the URL bar for the given index

Return Type:
  UrlBar

#### StackedUrlBar.urlBars

urlBars()

Public method to get a list of references to all URL bars.

Return:
  list of references to URL bars

Return Type:
  list of UrlBar

Up